<?php
// $Id: hansel.admin.inc,v 1.3 2010/08/16 18:31:15 mauritsl Exp $

/**
 * @file
 * Hansel admin pages
 */

/**
 * Page callback
 *
 * Generates the admin page
 */
function hansel_page() {
  $output = '';
  
  drupal_add_css(drupal_get_path('module', 'hansel') . '/hansel.admin.css');

  if ($rules = _hansel_list_rules()) {
    $output .= '<div id="hansel-rules">';
    $output .= $rules;
    $output .= '</div>';
  }
  else {
    // No rules are defined yet.
    $output .= '<p>' . t('You do not have any rules defined yet. You can create a new rule with the form below.') . '</p>';
    $output .= '<p>' . t('All configurations must have a rule with the name "start", which is the first rule to be executed.') . '</p>';
  }
  
  module_load_include('inc', 'hansel', 'hansel.forms');
  
  $output .= theme('box', t('Add rule'), drupal_get_form('hansel_rule_form'));
  
  return $output;
}

function _hansel_list_rules($pid = 0) {
  $output = '';
  foreach (_hansel_get_rules($pid) as $rule) {
    $delete_path = str_replace('%', $rule->rid, HANSEL_PATH_DELETE_RULE);
    $config_path = str_replace('%', $rule->rid, HANSEL_PATH_CONFIG_RULE);
    $delete_link = '<a href="' . url($delete_path) . '" class="hansel-delete-link"><span>delete</span></a>';
    $config_link = '<a href="' . url($config_path) . '" class="hansel-config-rule-link"><span>configure rule</span></a>';
    $output .= '<div class="hansel-rule">';
    
    // Add rule name, configure and delete link
    $output .= '<div class="hansel-name">';
    $output .= check_plain($rule->name);
    $output .= '<div class="hansel-buttons">' . $config_link . ' ' . $delete_link . '</div>';
    $output .= '</div>';
    
    $output .= '<div class="hansel-info">';
    
    // Add crumb info (if any)
    if (!empty($rule->crumb_action)) {
      $output .= '<div class="hansel-crumb-info">';
      $output .= _hansel_get_crumb_action_info($rule);
      $output .= '</div>';
    }
    
    // Add action info
    $output .= '<div class="hansel-type">';
    switch ($rule->action) {
      case 'goto':
        $sql = 'SELECT r.name FROM {hansel_rule} r WHERE r.rid = %d';
        $res = db_query($sql, $rule->destination);
        if (!$name = db_result($res)) {
          $name = t('(broken link)');
        }
        $output .= 'goto ' . check_plain($name);
        break;
      case 'leave':
        if ($rule->restore) {
          $output .= 'leave (restore original breadcrumbs)';
        }
        else {
          $output .= 'leave';
        }
        break;
      case 'switch':
        if (_hansel_is_configurable_switch($rule->handler)) {
          $config_path = str_replace('%', $rule->rid, HANSEL_PATH_CONFIG_SWITCH);
          $output .= 'switch on ' . l($rule->handler, $config_path);
        }
        else {
          $output .= 'switch on ' . check_plain($rule->handler);
        }
        $output .= ' ' . _hansel_get_switch_info($rule);
        break;
    }
    $output .= '</div>';

    // Add child rules (if any)
    $children = _hansel_list_rules($rule->rid);
    if ($children) {
      $output .= '<div class="hansel-children">' . $children . '</div>';
    }

    $output .= '</div>'; // Close .hansel-info
    $output .= '</div>'; // Close .hansel-rule
  }
  return $output;
}

/**
 * Page callback.
 *
 * Generates the settings page for Hansel.
 */
function hansel_settings($form_state) {
  $form = array();

  $form['hansel_breadcrumb_last_item_link'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('hansel_breadcrumb_last_item_link', TRUE),
    '#title' => t('Render last item as a link'),
    '#description' => t('When turned on, the last item in the breadcrumb will be a link.'),
  );

  return system_settings_form($form);
}
